fn persist_run_failures(config: &Config, outcome: &TestOutcome)Expand description
Replace the last run failures, clearing the record when the run succeeds.
fn persist_run_failures(config: &Config, outcome: &TestOutcome)Replace the last run failures, clearing the record when the run succeeds.