macro_rules! dispatch_network {
($evm_opts:expr, | $fen:ident | $body:expr) => { ... };
}Expand description
Evaluates $body with $fen bound to the concrete network type selected by $evm_opts.
macro_rules! dispatch_network {
($evm_opts:expr, | $fen:ident | $body:expr) => { ... };
}Evaluates $body with $fen bound to the concrete network type selected by $evm_opts.