pub struct TestArgs {Show 124 fields
fuzz_only: bool,
auto_fuzz_corpus: bool,
pub(crate) showmap_override: Option<ShowmapConfig>,
pub(crate) fuzz_failure_replay: bool,
pub(crate) invariant_runs_override: Option<u64>,
pub(crate) invariant_timeout_override: Option<u32>,
pub global: GlobalArgs,
pub path: Option<GlobMatcher>,
debug: bool,
debug_layout: Option<DebuggerLayout>,
flamegraph: bool,
flamechart: bool,
evm_profile: Option<EvmProfileFormat>,
no_open: bool,
tracing: TracingArgs,
dump: Option<PathBuf>,
gas_report: bool,
gas_snapshot_check: Option<bool>,
gas_snapshot_emit: Option<bool>,
allow_failure: bool,
suppress_successful_traces: bool,
json_file: Option<PathBuf>,
pub junit: bool,
pub fail_fast: bool,
etherscan_api_key: Option<String>,
list: bool,
pub fuzz_seed: Option<U256>,
pub fuzz_runs: Option<u64>,
pub invariant_workers: Option<InvariantWorkers>,
pub fuzz_run: Option<u32>,
pub fuzz_worker: Option<u32>,
pub fuzz_timeout: Option<u64>,
pub fuzz_dictionary_weight: Option<u32>,
pub fuzz_dictionary_addresses: Option<String>,
pub fuzz_dictionary_values: Option<String>,
pub fuzz_dictionary_literals: Option<String>,
pub fuzz_corpus_random_sequence_weight: Option<u32>,
pub fuzz_corpus_dir: Option<PathBuf>,
pub fuzz_frontier_dir: Option<PathBuf>,
pub fuzz_frontier_limit: Option<usize>,
pub fuzz_payable_value_weight: Option<u32>,
pub fuzz_mutation_weight_splice: Option<u32>,
pub fuzz_mutation_weight_repeat: Option<u32>,
pub fuzz_mutation_weight_interleave: Option<u32>,
pub fuzz_mutation_weight_prefix: Option<u32>,
pub fuzz_mutation_weight_suffix: Option<u32>,
pub fuzz_mutation_weight_abi: Option<u32>,
pub fuzz_mutation_weight_cmp: Option<u32>,
pub fuzz_input_file: Option<PathBuf>,
pub invariant_depth: Option<u32>,
pub invariant_min_depth: Option<u32>,
pub invariant_depth_mode: Option<InvariantDepthMode>,
pub invariant_dictionary_weight: Option<u32>,
pub invariant_dictionary_addresses: Option<String>,
pub invariant_dictionary_values: Option<String>,
pub invariant_dictionary_literals: Option<String>,
pub invariant_corpus_random_sequence_weight: Option<u32>,
pub invariant_corpus_dir: Option<PathBuf>,
pub invariant_frontier_dir: Option<PathBuf>,
pub invariant_frontier_limit: Option<usize>,
pub invariant_payable_value_weight: Option<u32>,
pub invariant_mutation_weight_splice: Option<u32>,
pub invariant_mutation_weight_repeat: Option<u32>,
pub invariant_mutation_weight_interleave: Option<u32>,
pub invariant_mutation_weight_prefix: Option<u32>,
pub invariant_mutation_weight_suffix: Option<u32>,
pub invariant_mutation_weight_abi: Option<u32>,
pub invariant_mutation_weight_cmp: Option<u32>,
pub symbolic: bool,
pub replay_symbolic_artifact: Option<PathBuf>,
pub emit_regression: bool,
pub regression_out: Option<PathBuf>,
pub regression_overwrite: bool,
pub symbolic_seed_corpus: bool,
pub symbolic_use_fuzz_corpus: bool,
pub symbolic_corpus_seed_limit: Option<usize>,
pub symbolic_use_fuzz_frontiers: bool,
pub symbolic_check_invariant_frontiers: bool,
pub symbolic_frontier_limit: Option<usize>,
pub symbolic_frontier_ids: Option<Vec<u64>>,
pub symbolic_frontier_pcs: Option<Vec<usize>>,
pub symbolic_frontier_selectors: Option<Vec<String>>,
pub symbolic_solver: Option<String>,
pub symbolic_solver_command: Option<String>,
pub symbolic_solver_portfolio: Option<Vec<String>>,
pub symbolic_timeout: Option<u32>,
pub symbolic_loop: Option<u32>,
pub symbolic_depth: Option<u32>,
pub symbolic_width: Option<u32>,
pub symbolic_max_depth: Option<u32>,
pub symbolic_max_paths: Option<u32>,
pub symbolic_invariant_depth: Option<u32>,
pub symbolic_max_solver_queries: Option<u32>,
pub symbolic_default_dynamic_length: Option<u32>,
pub symbolic_max_dynamic_length: Option<u32>,
pub symbolic_array_lengths: Option<Vec<u32>>,
pub symbolic_max_calldata_bytes: Option<u32>,
pub symbolic_call_targets: bool,
pub symbolic_dump_smt: bool,
pub symbolic_storage_layout: Option<String>,
pub show_progress: bool,
pub rerun: bool,
pub opcodes: Vec<OpCode>,
pub summary: bool,
pub detailed: bool,
pub showmap_out: Option<PathBuf>,
pub showmap_per_input: bool,
pub showmap_domain: ShowmapDomainArg,
pub showmap_approach: String,
pub showmap_trial: Option<String>,
pub showmap_corpus_dir: Option<PathBuf>,
pub decode_external_storage: bool,
filter: FilterArgs,
evm: EvmArgs,
pub build: BuildOpts,
pub watch: WatchArgs,
pub mutate: Option<Vec<PathBuf>>,
pub mutate_path: Option<GlobMatcher>,
pub mutate_contract: Option<Regex>,
pub mutation_jobs: Option<usize>,
pub mutation_timeout: Option<u32>,
pub mutation_optimizer_runs: Option<u32>,
pub mutation_via_ir: Option<bool>,
pub brutalize: bool,
}Expand description
CLI arguments for forge test.
Fields
fuzz_only: boolInternal mode used by forge fuzz to run only fuzz and invariant tests.
auto_fuzz_corpus: boolInternal mode used by forge fuzz run to default the fuzz corpus dir.
showmap_override: Option<ShowmapConfig>Internal showmap/replay override used by forge fuzz replay.
fuzz_failure_replay: boolInternal mode used by forge fuzz replay to replay persisted fuzz failures.
invariant_runs_override: Option<u64>Internal override used by forge fuzz run --runs for invariant campaigns.
invariant_timeout_override: Option<u32>Internal override used by forge fuzz run --timeout for invariant campaigns.
global: GlobalArgspath: Option<GlobMatcher>The contract file you want to test, it’s a shortcut for –match-path.
debug: boolRun a single test in the debugger.
The matching test will be opened in the debugger regardless of the outcome of the test.
If the matching test is a fuzz test, then it will open the debugger on the first failure case. If the fuzz test does not fail, it will open the debugger on the last fuzz case.
debug_layout: Option<DebuggerLayout>Debugger layout to use.
flamegraph: boolGenerate a flamegraph for a single test. Implies --decode-internal.
A flame graph is used to visualize which functions or operations within the smart contract are consuming the most gas overall in a sorted manner.
flamechart: boolGenerate a flamechart for a single test. Implies --decode-internal.
A flame chart shows the gas usage over time, illustrating when each function is called (execution order) and how much gas it consumes at each point in the timeline.
evm_profile: Option<EvmProfileFormat>Generate an execution profile for a single test.
Creates a profile where each EVM call is recorded with gas consumption.
Opens the profile in speedscope.app unless --no-open is passed.
Implies --decode-internal.
no_open: boolDon’t open the generated profile, flamegraph, or flamechart.
The profile is saved to disk without starting the local viewer server.
tracing: TracingArgsdump: Option<PathBuf>Dumps all debugger steps to file.
gas_report: boolPrint a gas report.
gas_snapshot_check: Option<bool>Check gas snapshots against previous runs.
gas_snapshot_emit: Option<bool>Enable/disable recording of gas snapshot results.
allow_failure: boolExit with code 0 even if a test fails.
suppress_successful_traces: boolSuppress successful test traces and show only traces for failures.
json_file: Option<PathBuf>Write test results as JSON to the specified file.
junit: boolOutput test results as JUnit XML report.
fail_fast: boolStop running tests after the first failure.
etherscan_api_key: Option<String>The Etherscan (or equivalent) API key.
list: boolList tests instead of running them.
fuzz_seed: Option<U256>Set seed used to generate randomness during your fuzz runs.
fuzz_runs: Option<u64>invariant_workers: Option<InvariantWorkers>Number of workers to use for invariant test campaigns, or auto to derive from --jobs.
fuzz_run: Option<u32>Run only the fuzz case at the given 1-based run index.
fuzz_worker: Option<u32>Run the fuzz case from the given worker. Requires --fuzz-run.
fuzz_timeout: Option<u64>Timeout for each fuzz run in seconds.
fuzz_dictionary_weight: Option<u32>Percent of fuzz calldata generated from the dictionary.
fuzz_dictionary_addresses: Option<String>Maximum fuzz dictionary addresses, or max.
fuzz_dictionary_values: Option<String>Maximum fuzz dictionary values, or max.
fuzz_dictionary_literals: Option<String>Maximum fuzz dictionary literals, or max.
fuzz_corpus_random_sequence_weight: Option<u32>Percent chance that coverage-guided fuzzing generates fresh input instead of mutating corpus input.
fuzz_corpus_dir: Option<PathBuf>Directory for fuzz corpus persistence.
fuzz_frontier_dir: Option<PathBuf>Directory for fuzz branch frontier artifacts.
fuzz_frontier_limit: Option<usize>Maximum number of fuzz branch frontier records to write per test.
fuzz_payable_value_weight: Option<u32>Percent chance that fuzzed payable calls carry non-zero msg.value.
fuzz_mutation_weight_splice: Option<u32>Corpus mutation weight for splice.
fuzz_mutation_weight_repeat: Option<u32>Corpus mutation weight for repeat.
fuzz_mutation_weight_interleave: Option<u32>Corpus mutation weight for interleave.
fuzz_mutation_weight_prefix: Option<u32>Corpus mutation weight for prefix replacement.
fuzz_mutation_weight_suffix: Option<u32>Corpus mutation weight for suffix replacement.
fuzz_mutation_weight_abi: Option<u32>Corpus mutation weight for ABI argument mutation.
fuzz_mutation_weight_cmp: Option<u32>Corpus mutation weight for comparison-operand mutation.
fuzz_input_file: Option<PathBuf>File to rerun fuzz failures from.
invariant_depth: Option<u32>Number of calls executed to try to break invariants in one run.
invariant_min_depth: Option<u32>Minimum sampled invariant depth when --invariant-depth-mode random is active.
invariant_depth_mode: Option<InvariantDepthMode>How invariant run depth is selected.
invariant_dictionary_weight: Option<u32>Percent of invariant calldata/senders generated from the dictionary.
invariant_dictionary_addresses: Option<String>Maximum invariant dictionary addresses, or max.
invariant_dictionary_values: Option<String>Maximum invariant dictionary values, or max.
invariant_dictionary_literals: Option<String>Maximum invariant dictionary literals, or max.
invariant_corpus_random_sequence_weight: Option<u32>Percent chance that coverage-guided invariant fuzzing injects fresh calls while extending corpus sequences.
invariant_corpus_dir: Option<PathBuf>Directory for invariant corpus persistence.
invariant_frontier_dir: Option<PathBuf>Directory for invariant branch frontier artifacts.
invariant_frontier_limit: Option<usize>Maximum number of invariant branch frontier records to write per campaign.
invariant_payable_value_weight: Option<u32>Percent chance that fuzzed payable invariant calls carry non-zero msg.value.
invariant_mutation_weight_splice: Option<u32>Corpus mutation weight for splice.
invariant_mutation_weight_repeat: Option<u32>Corpus mutation weight for repeat.
invariant_mutation_weight_interleave: Option<u32>Corpus mutation weight for interleave.
invariant_mutation_weight_prefix: Option<u32>Corpus mutation weight for prefix replacement.
invariant_mutation_weight_suffix: Option<u32>Corpus mutation weight for suffix replacement.
invariant_mutation_weight_abi: Option<u32>Corpus mutation weight for ABI argument mutation.
invariant_mutation_weight_cmp: Option<u32>Corpus mutation weight for comparison-operand mutation.
symbolic: boolRun symbolic check*/prove*/invariant*/statefulFuzz* tests.
replay_symbolic_artifact: Option<PathBuf>Replay a durable symbolic counterexample artifact emitted by forge test --symbolic.
emit_regression: boolEmit Solidity regression tests for confirmed symbolic counterexamples.
regression_out: Option<PathBuf>File or directory for generated symbolic regression tests.
regression_overwrite: boolOverwrite existing generated symbolic regression tests.
symbolic_seed_corpus: boolRun fuzz tests symbolically and persist non-failing concrete inputs to the fuzz corpus.
symbolic_use_fuzz_corpus: boolRun fuzz tests symbolically using existing fuzz corpus entries as path-priority hints.
symbolic_corpus_seed_limit: Option<usize>Maximum number of fuzz corpus entries to import for one symbolic test.
symbolic_use_fuzz_frontiers: boolRun targeted symbolic solving from existing fuzz branch frontier artifacts.
symbolic_check_invariant_frontiers: boolCheck invariants from imported stateful fuzz frontier prefixes before flipping comparisons.
symbolic_frontier_limit: Option<usize>Maximum number of fuzz branch frontiers to try for one symbolic test.
symbolic_frontier_ids: Option<Vec<u64>>Comma-separated fuzz branch frontier artifact IDs to try.
symbolic_frontier_pcs: Option<Vec<usize>>Comma-separated fuzz branch frontier comparison PCs to try.
symbolic_frontier_selectors: Option<Vec<String>>Comma-separated fuzz branch frontier calldata selectors to try.
symbolic_solver: Option<String>Solver executable used for symbolic tests.
symbolic_solver_command: Option<String>Exact solver command used for symbolic tests.
symbolic_solver_portfolio: Option<Vec<String>>Comma-separated SMT solver names or commands to race in parallel for symbolic tests.
symbolic_timeout: Option<u32>SMT solver timeout in seconds; also bounds symbolic invariant exploration.
symbolic_loop: Option<u32>Halmos-compatible symbolic loop bound.
symbolic_depth: Option<u32>Halmos-compatible symbolic execution depth alias.
symbolic_width: Option<u32>Halmos-compatible symbolic path width alias.
symbolic_max_depth: Option<u32>Maximum number of opcodes executed along a symbolic path.
symbolic_max_paths: Option<u32>Maximum number of symbolic paths to explore per test.
symbolic_invariant_depth: Option<u32>Maximum number of calls in a bounded symbolic invariant sequence.
symbolic_max_solver_queries: Option<u32>Maximum number of solver queries per symbolic test.
symbolic_default_dynamic_length: Option<u32>Default bounded length for symbolic dynamic ABI inputs.
symbolic_max_dynamic_length: Option<u32>Maximum permitted bounded length for symbolic dynamic ABI inputs.
symbolic_array_lengths: Option<Vec<u32>>Per-dynamic-input symbolic lengths, applied in ABI traversal order.
symbolic_max_calldata_bytes: Option<u32>Maximum symbolic calldata size in bytes.
symbolic_call_targets: boolExpand symbolic external call targets over known deployed contracts.
symbolic_dump_smt: boolDump SMT-LIB queries issued by symbolic tests.
symbolic_storage_layout: Option<String>Symbolic storage modelling mode.
show_progress: boolShow test execution progress.
rerun: boolRe-run recorded test failures from last run. If no failure recorded then regular test run is performed.
opcodes: Vec<OpCode>Print the given opcodes in trace output, with their gas cost and the storage slot and value, if available.
Accepts a comma-separated list of opcode names, e.g.
--opcodes SLOAD,MLOAD,SSTORE. Names are in uppercase.
Requires -vvvvv to render.
summary: boolPrint test summary table.
detailed: boolPrint detailed test summary table.
showmap_out: Option<PathBuf>Replay the persisted corpus and emit AFL-afl-showmap-style coverage
files at the given output directory. Disables the regular fuzz/invariant
campaign and skips unit tests.
showmap_per_input: boolEmit one showmap file per corpus entry (default: one aggregated file per test).
showmap_domain: ShowmapDomainArgCoverage domain(s) to dump.
showmap_approach: StringApproach name (used as a subdirectory of --showmap-out).
showmap_trial: Option<String>Trial identifier embedded in each showmap filename. Defaults to a unique
trial-<unix_nanos> so reruns don’t overwrite previous trials.
showmap_corpus_dir: Option<PathBuf>Override the corpus directory to replay (defaults to the per-test
corpus_dir resolved from config).
decode_external_storage: boolDecode the storage layouts of contracts outside the local project in state diffs, by compiling the verified source a block explorer has for them.
filter: FilterArgsevm: EvmArgsbuild: BuildOptswatch: WatchArgsmutate: Option<Vec<PathBuf>>Enable mutation testing. If passed with file paths, only those files will be tested.
mutate_path: Option<GlobMatcher>Specify which files to mutate with glob pattern matching.
Mutually exclusive with passing explicit paths to --mutate; either
supply paths to --mutate or use this glob filter, not both.
mutate_contract: Option<Regex>Only mutate contracts whose name matches the specified regex pattern.
Mutually exclusive with --mutate-path.
mutation_jobs: Option<usize>Number of parallel workers for mutation testing. Defaults to the number of CPU cores.
mutation_timeout: Option<u32>Best-effort per-mutant wall-clock timeout in seconds. Mutants that exceed it are recorded as “timed out” and cleanup continues in the background with bounded pending workers.
Analogous to --invariant-timeout for invariant campaigns.
mutation_optimizer_runs: Option<u32>Override optimizer runs for mutation testing compile-and-test runs.
mutation_via_ir: Option<bool>Override via-ir for mutation testing compile-and-test runs.
brutalize: boolEnable brutalization mode.
Catches latent bugs that normal tests miss because the EVM initializes memory to zero and registers to clean values. Applies source-level sanitizers before compiling:
- Dirties unused bits in sub-256-bit type casts (address, uint8, bytes4, etc.) to catch assembly code that assumes clean upper bits when using legacy codegen. Via-IR may clean these bits before inline assembly observes them.
- Fills scratch space (0x00-0x3f) and memory beyond the free memory pointer with junk to catch uninitialized memory reads
- Misaligns the free memory pointer to catch word-alignment assumptions
If forge test passes but forge test --brutalize fails, the code has
a robustness issue that could manifest when called in a different context.
Implementations
Sourceimpl TestArgs
impl TestArgs
pub async fn run(self) -> Result<TestOutcome>
pub(crate) fn ensure_mutation_mode_compatible( &self, coverage: bool, ) -> Result<()>
pub(crate) fn ensure_coverage_mode_compatible(&self) -> Result<()>
Sourcefn showmap_config(&self) -> Result<Option<ShowmapConfig>>
fn showmap_config(&self) -> Result<Option<ShowmapConfig>>
Builds a ShowmapConfig from the showmap CLI flags, if --showmap-out is set.
Sourcepub(crate) const fn enable_fuzz_only(&mut self)
pub(crate) const fn enable_fuzz_only(&mut self)
Restricts this test invocation to fuzz and invariant tests.
Sourcepub(crate) const fn enable_fuzz_only_with_auto_fuzz_corpus(&mut self)
pub(crate) const fn enable_fuzz_only_with_auto_fuzz_corpus(&mut self)
Restricts this test invocation to fuzz and invariant tests and enables a default fuzz corpus dir after user config is loaded.
fn apply_test_config_overrides(&self, config: &mut Config)
Sourceconst fn apply_gas_report_overrides(
&self,
config: &mut Config,
evm_opts: &mut EvmOpts,
)
const fn apply_gas_report_overrides( &self, config: &mut Config, evm_opts: &mut EvmOpts, )
Disables gas report sampling unless a gas report is requested, in which case isolation is enabled for more correct gas accounting.
Sourcepub(crate) fn set_showmap_override(&mut self, showmap: ShowmapConfig)
pub(crate) fn set_showmap_override(&mut self, showmap: ShowmapConfig)
Overrides showmap config for callers that reuse replay mode without the
forge test --showmap-* CLI flags.
Sourcepub(crate) fn set_fuzz_minimize_replay_options(
&mut self,
global: GlobalArgs,
evm: EvmArgs,
build: BuildOpts,
filter: FilterArgs,
)
pub(crate) fn set_fuzz_minimize_replay_options( &mut self, global: GlobalArgs, evm: EvmArgs, build: BuildOpts, filter: FilterArgs, )
Sets replay-critical options for internal fuzz minimizer callers.
Sourcepub(crate) const fn enable_fuzz_failure_replay(&mut self)
pub(crate) const fn enable_fuzz_failure_replay(&mut self)
Replays persisted fuzz failures without running a new fuzz campaign.
fn warn_unsupported_engine_flags( &self, output: &ProjectCompileOutput, config: &Config, inline_config: &InlineConfig, filter: &ProjectPathsAwareFilter, multi_network: &MultiNetworkConfig, ) -> Result<()>
Sourcepub(crate) fn from_fuzz_run(args: FuzzRunArgs) -> Self
pub(crate) fn from_fuzz_run(args: FuzzRunArgs) -> Self
Builds the delegated forge test invocation for forge fuzz run.
fn load_symbolic_artifact_replay( &self, ) -> Result<Option<SymbolicArtifactReplayConfig>>
fn load_fuzz_input( &self, output: &ProjectCompileOutput, config: &Config, inline_config: &InlineConfig, filter: &ProjectPathsAwareFilter, ) -> Result<Option<FuzzFailureReplayConfig>>
Sourcefn get_sources_to_compile(
&self,
config: &Config,
test_filter: &ProjectPathsAwareFilter,
symbolic_artifact_replay: Option<&SymbolicArtifactReplayConfig>,
) -> Result<(BTreeSet<PathBuf>, Option<Arc<InlineConfig>>)>
fn get_sources_to_compile( &self, config: &Config, test_filter: &ProjectPathsAwareFilter, symbolic_artifact_replay: Option<&SymbolicArtifactReplayConfig>, ) -> Result<(BTreeSet<PathBuf>, Option<Arc<InlineConfig>>)>
Returns a list of files that need to be compiled in order to run all the tests that match the given filter, and the inline config parsed from the ABI-only compilation when one was needed.
For filtered runs, this includes all configured source roots, non-test fixture roots, and runnable tests that match the filter. Imported dependencies remain attached to those roots so compiler profiles and restrictions apply to the complete source graph.
Sourcepub async fn compile_and_run(&mut self) -> Result<TestOutcome>
pub async fn compile_and_run(&mut self) -> Result<TestOutcome>
Executes all the tests in the project.
This will trigger the build process first. On success all test contracts that match the configured filter will be executed
Returns the test results for all matching tests.
Sourcefn brutalize_workspace(&self, config: &mut Config) -> Result<TempDir>
fn brutalize_workspace(&self, config: &mut Config) -> Result<TempDir>
Copies the project into a temporary workspace, brutalizes its sources and rebases config
onto that workspace.
async fn compile_project(&mut self) -> Result<CompiledTestProject>
pub(crate) async fn prepare_fuzz_minimize_replay( &mut self, corpus_dir: &Path, ) -> Result<FuzzMinimizeReplaySession>
Sourcepub(crate) async fn run_tests(
&mut self,
project_root: &Path,
config: Config,
evm_opts: EvmOpts,
output: &ProjectCompileOutput,
filter: &ProjectPathsAwareFilter,
execution: TestExecutionOptions,
) -> Result<TestOutcome>
pub(crate) async fn run_tests( &mut self, project_root: &Path, config: Config, evm_opts: EvmOpts, output: &ProjectCompileOutput, filter: &ProjectPathsAwareFilter, execution: TestExecutionOptions, ) -> Result<TestOutcome>
Executes all the tests in the project.
See Self::compile_and_run for more details.
Sourceasync fn render_trace_output(
&self,
trace_output: TraceOutputKind,
outcome: &mut TestOutcome,
) -> Result<()>
async fn render_trace_output( &self, trace_output: TraceOutputKind, outcome: &mut TestOutcome, ) -> Result<()>
Renders the flamegraph, flamechart or EVM profile of the single executed test.
Sourceasync fn build_runner<FEN: FoundryEvmNetwork>(
&self,
config: Arc<Config>,
evm_opts: EvmOpts,
output: &ProjectCompileOutput,
execution: TestExecutionOptions,
resolved_fork: Option<&ResolvedFork>,
executor_builder: ExecutorBuilder<FEN>,
) -> Result<MultiContractRunner<FEN>>
async fn build_runner<FEN: FoundryEvmNetwork>( &self, config: Arc<Config>, evm_opts: EvmOpts, output: &ProjectCompileOutput, execution: TestExecutionOptions, resolved_fork: Option<&ResolvedFork>, executor_builder: ExecutorBuilder<FEN>, ) -> Result<MultiContractRunner<FEN>>
Builds the test runner for the network selected by evm_opts.
Sourceasync fn run_network_pass(
&self,
pass: NetworkPass,
output: &ProjectCompileOutput,
filter: &mut ProjectPathsAwareFilter,
execution: TestExecutionOptions,
resolved_fork: Option<&ResolvedFork>,
) -> Result<(Libraries, TestOutcome)>
async fn run_network_pass( &self, pass: NetworkPass, output: &ProjectCompileOutput, filter: &mut ProjectPathsAwareFilter, execution: TestExecutionOptions, resolved_fork: Option<&ResolvedFork>, ) -> Result<(Libraries, TestOutcome)>
Builds the runner for one network pass and runs its tests.
Sourcefn emit_symbolic_regressions(
&self,
config: &Config,
known_contracts: &ContractsByArtifact,
results: &mut BTreeMap<String, SuiteResult>,
) -> Result<Vec<SymbolicRegression>>
fn emit_symbolic_regressions( &self, config: &Config, known_contracts: &ContractsByArtifact, results: &mut BTreeMap<String, SuiteResult>, ) -> Result<Vec<SymbolicRegression>>
Emits symbolic regression tests for the counterexample artifacts in results when
--emit-regression is set, and attaches them to the results.
Sourcefn print_summary(&self, outcome: &TestOutcome, duration: Duration) -> Result<()>
fn print_summary(&self, outcome: &TestOutcome, duration: Duration) -> Result<()>
Prints the run summary, or the detailed summary table when --summary is set.
Sourceasync fn run_tests_inner<FEN: FoundryEvmNetwork>(
&self,
runner: MultiContractRunner<FEN>,
config: Arc<Config>,
verbosity: u8,
filter: &mut ProjectPathsAwareFilter,
output: &ProjectCompileOutput,
) -> Result<TestOutcome>
async fn run_tests_inner<FEN: FoundryEvmNetwork>( &self, runner: MultiContractRunner<FEN>, config: Arc<Config>, verbosity: u8, filter: &mut ProjectPathsAwareFilter, output: &ProjectCompileOutput, ) -> Result<TestOutcome>
Run all tests that matches the filter predicate from a test runner
Sourcefn check_and_write_gas_snapshots(
&self,
config: &Config,
gas_snapshots: &BTreeMap<String, BTreeMap<String, String>>,
) -> Result<()>
fn check_and_write_gas_snapshots( &self, config: &Config, gas_snapshots: &BTreeMap<String, BTreeMap<String, String>>, ) -> Result<()>
Compares the collected gas snapshots against the ones on disk and writes them back,
depending on --gas-snapshot-check / --gas-snapshot-emit and their config defaults.
The CLI flags override the config and environment, so --gas-snapshot-check=false disables
a check enabled in the config. Exits with code 1 if differences are found.
Sourcepub fn filter(&self, config: &Config) -> Result<ProjectPathsAwareFilter>
pub fn filter(&self, config: &Config) -> Result<ProjectPathsAwareFilter>
Returns the flattened FilterArgs arguments merged with Config.
Loads and applies filter from file if only last test run failures performed.
Sourcepub(crate) fn watchexec_config(&self) -> Result<Config>
pub(crate) fn watchexec_config(&self) -> Result<Config>
Returns the [watchexec::Config] necessary to bootstrap a new watch loop.